function return_data = clf_double_wall(f,connection_values,plate_values,cavity_values)
%
% 110516 PA clf_doulbe_wall.m
%           Correted so that mass per unit area (m1,m2) are used in the 
%           formulas for double wall resonance (fdw=...) and 
%           transmission coefficient (tau(1,5,2).l(...)=...)
%           instead of the density (plate_values(?).rho)
% 110516 PA clf_double_wall.m
%           Corrected the calculation of CLFs for the small cavity (in the
%           double wall) to the larger cacities (rooms). The calc. uses
%           reciprocity, but the modal densities were mixed. It now reads 
%           eta_ij=n_j/n_i*eta_ji instead of eta_ij=n_i/n_j*eta_ji.
%
cavs = [1 3 5];
plates = [2 4];
for ii = 1:length(cavs)
    rho0(ii) = cavity_values(ii).rho;
    c0(ii) = cavity_values(ii).c;
end
tau(1:5,1:5,1:3) = struct('b',zeros(1,length(f)),'l',zeros(1,length(f)),'s',zeros(1,length(f)));
clf(1:5,1:5,1:3) = struct('b',zeros(1,length(f)),'l',zeros(1,length(f)),'s',zeros(1,length(f)));
for leafs = 1:2
    rad_return(leafs) = plate_cavity_rad_tau(f,plate_values(leafs),cavity_values(leafs:(leafs+1)),0.02);
    h(leafs) = plate_values(leafs).thickness;
    rho(leafs) = plate_values(leafs).rho*h(leafs);
    fc(leafs).left = c0(leafs)^2./(1.8*plate_values(leafs).c.l(1)*h(leafs));
    fc(leafs).right = c0(leafs+1)^2./(1.8*plate_values(leafs).c.l(1)*h(leafs));
    clf(plates(leafs),cavs(leafs),1).l = rho0(leafs)*c0(leafs)*rad_return(leafs).rad(1).rad./(2*pi*f*rho(leafs));
    clf(plates(leafs),cavs(leafs+1),1).l = rho0(leafs+1)*c0(leafs+1)*rad_return(leafs).rad(2).rad./(2*pi*f*rho(leafs));
    clf(cavs(leafs),plates(leafs),2).b = clf(plates(leafs),cavs(leafs),1).l.*plate_values(leafs).mden.b./cavity_values(leafs).mden.l;
    clf(cavs(leafs+1),plates(leafs),2).b = clf(plates(leafs),cavs(leafs+1),1).l.*plate_values(leafs).mden.b./cavity_values(leafs+1).mden.l;
end
clf(1,3,2).l = c0(1)*connection_values.area*rad_return(1).tau(1).tau./(8*pi*f*cavity_values(1).volume);
clf(5,3,2).l = c0(3)*connection_values.area*rad_return(2).tau(2).tau./(8*pi*f*cavity_values(3).volume);
clf(3,1,2).l = clf(1,3,2).l.*cavity_values(1).mden.l./cavity_values(2).mden.l; % 110516 PA corrected formulas
clf(3,5,2).l = clf(5,3,2).l.*cavity_values(3).mden.l./cavity_values(2).mden.l; % 110516 PA corrected formulas
K = rho0(2)*c0(2)^2/cavity_values(2).dim(3);
m1=plate_values(1).rho*plate_values(1).thickness; % 110516 PA using mass per unit area instead of density
m2=plate_values(2).rho*plate_values(2).thickness; % 110516 PA using mass per unit area instead of density
fdw=(1/(2*pi))*sqrt(K*((m1+m2)/(m1*m2))); % 110516 PA using mass per unit area instead of density
fd=55/cavity_values(2).dim(3);
tau(1,5,2).l(f<=fdw) = 10.^(-((20*log10(f(f<=fdw).*(m1+m2))-47)/10)); % 110516 PA using mass per unit area instead of density
tau(1,5,2).l(fdw<f & f<fd) = 10.^(-((20*log10(f(fdw<f & f<fd)*m1)-47+20*log10(f(fdw<f & f<fd)*m2)-47+20*log10(f(fdw<f & f<fd)*cavity_values(2).dim(3))-29)/10)); % 110516 PA using mass per unit area instead of density
tau(1,5,2).l(f>=fd) = 10.^(-((20*log10(f(f>=fd)*m1)-47+20*log10(f(f>=fd)*m2)-47+6)/10)); % 110516 PA using mass per unit area instead of density
tau(5,1,2).l = tau(1,5,2).l;
clf(1,5,2).l = (c0(1)*connection_values.area*tau(1,5,2).l)./(8*pi*f*cavity_values(1).volume);
clf(5,1,2).l = (c0(3)*connection_values.area*tau(1,5,2).l)./(8*pi*f*cavity_values(3).volume);

return_data = clf;