function return_data = clf_leaf_wall(f,plate_values,cavity_values,con_values)
%
% 110516 PA clf_leaf_wall.m
%           The 'masslaw' CLF for the smallest cavity to largest cavity CLF is calc. using reciprociy, 
%           i.e. CLF12=n2/n1*CLF21 where CLF21 for the largest to the smallest of the two cavities
%           This avoids calculations problems when small cavities behaves as 2D cavitities
% 110516 PA clf_leaf_wall.m
%           Corrected the position of 'cavs2 = cavs2 + 1;'; it is now outside the 
%           'if cavs_nr~=cavs_nr2'-condition so it increases also when looping over the 
%           "from" subsystem itself ('cavs_nr' subsystem)    

numcavs = length(cavity_values);
numss = length(con_values.subsystems);
h = plate_values.thickness;
rho = plate_values.rho*h;
rho0(1:numcavs) = 0;
c0(1:numcavs) = 0;
fc(1:numcavs) = 0;
for cavs = 1:numcavs
    rho0(cavs) = cavity_values(cavs).rho;
    c0(cavs) = cavity_values(cavs).c;
    fc(cavs) = c0(cavs)^2./(1.8*plate_values.c.l(1)*h);
end
clf(1:numss,1:numss,1:3) = struct('b',zeros(1,length(f)),'l',zeros(1,length(f)),'s',zeros(1,length(f)));
cavs = 0;
for cavs_nr = con_values.cavity_nr
    cavs = cavs + 1;
    plate_pos = find(con_values.plate_nr==con_values.subsystems);
    cavs_pos = find(cavs_nr==con_values.subsystems);
    clf(plate_pos,cavs_pos,1).l = rho0(cavs)*c0(cavs)*con_values.radiation_eff(cavs).rad./(2*pi*f*rho);
    clf(cavs_pos,plate_pos,2).b = clf(plate_pos,cavs_pos,1).l.*plate_values.mden.b./cavity_values(cavs).mden.l;
    if numcavs >1
        cavs2 = 0;
        for cavs_nr2 = con_values.cavity_nr
            cavs2 = cavs2 + 1; % 110516 PA New position
            if cavs_nr~=cavs_nr2
                cavs_pos2 = cavs_nr2==con_values.subsystems;
                if cavity_values(cavs).volume>cavity_values(cavs2).volume % 110516 PA Using the CLF from the larges room
                    clf(cavs_pos,cavs_pos2,2).l = c0(cavs)*con_values.values.area*con_values.tau(cavs2).tau./(8*pi*f*cavity_values(cavs).volume);
                else % 110516 PA:
                    clf(cavs_pos,cavs_pos2,2).l = c0(cavs2)*con_values.values.area*con_values.tau(cavs).tau./(8*pi*f*cavity_values(cavs2).volume)...
                                                .*cavity_values(cavs2).mden.l./cavity_values(cavs).mden.l;
                end
            end
        end
    end
end
return_data = clf;

