function return_data = calc_D(subsystems,mater,h)
% calc_D(subsystems,mater,h) returns a double array containing the
% bending stiffnesses for the given subsystems (plates).
%
% [Usage]:
%   D = calc_D(subsystems,mater,h)
%
% [Inputs]:
%   subsystems (double array) - vector containing the numbers of the
%                               subsystems (according to the SEA system)
%   mater (double array) - vector of the corresponing material numbers for
%                          the subsystems (corresponding to the material
%                          numbers in the data file physicalproperties.mat)
%   h (double array) - the plate thickness of the subsystems [m]
%
% [Output]:
%   D (double array) - vector containing each subsystems bending stiffness
%

% load all material properties and keep them persistent within the function
% to prevent unnecessary load times.
persistent solids
if (isempty(solids))
    load physicalproperties solids
end
% calculate the bending stiffness for specific material
for subs = 1:length(subsystems)
    E(subs).y = solids.Ey(mater(subs));
    poi(subs) = solids.poi(mater(subs));
    D(subs) = (E(subs).y*h(subs)^3)/(12*(1-poi(subs)^2));
end
% return bending stiffness.
return_data = D;