function return_data = calc_c(k,f)
% calc_c(k,f) returns a structure array containing the wave speeds for
% a given wavenumber structurearray, k, and a given frequency vector, f.
%
% [Usage]:
%   c = calc_c(k,f)
%
% [Inputs]:
%   k (structure)       - fields: b - Bending wavenumber vector
%                                 l - Longitudinal wavenumber vector
%                                 s - Shear wavenumber vector
%   f (double array)    - Frequency vector
%
% [Output]:
%   c (structure)       - fields: b - Bending wave speed
%                                 l - Longitudinal wave speed
%                                 s - Shear wave speed
%

w = 2*pi*f; % angular frequency.
% pre allocate memory for structur array.
c(1:length(k)) = struct('b',[],'l',[],'s',[]);
% calculate the wavespeed from the given wavenumbers and frequency.
for ii = 1:length(k)
    c(ii).b = w./k(ii).b;
    c(ii).l = w./k(ii).l;
    c(ii).s = w./k(ii).s;
end
% return wave speed structure array.
return_data = c;