function f = frequency(startfreq, endfreq, type, freqstep)
% frequency(startfreq,endfreq,type,freqstep) returns a frequency vector of
% a specific bandwidth between defined frequencies.
%
% [Usage]:
%   f = frequency(startfreq, endfreq, type, freqstep)
%
% [Inputs]:
%   startfreq (double) - Center frequency of first frequency band or start
%                        frequency in a linear frequency spectra.
%   endfreq (double)   - Center frequency of last frequency band or the end
%                        frequency in a linear frequency spectra.
%   type (string)      - Type of frequency spectra:
%                           'octave'  for octave band.
%                           '13octave' for 1/3-octave band.
%                           'linear' for linear spectra.
%   freqstep (double)  - Frequency step
%                        (only given for linear frequency spectra)
%
% [Output]:
%   f - The frequency spectra of given type and frequency range
%

% load predefined 1/3-octave band and octave band centre frequencies.
load frequencies.mat fr13oct froct
% return center frequencies for the frequency range and frequency band of
% interest.
if nargin == 3;
    if strcmp(type,'octave')
        f = froct(find(froct==startfreq):find(froct==endfreq));
    elseif strcmp(type,'13octave')
        f = fr13oct(find(fr13oct==startfreq):find(fr13oct==endfreq));
    end
% return linear frequency vector
elseif nargin == 4
    if strcmp(type,'linear')
        f = startfreq:freqstep:endfreq;
    end
end