function varargout = mainui(varargin)
% mainui is a graphical interface to set up a structure and their
% properties to calculate energy transmission and sound radiation.
% 
%  These Interface is tested and runnable under R2010a
% 
%  Needed Files:      * *.m etc.
%
%  Needs to be called from the main.m file to store variables used during
%  the creation phase of the interface.
%
%  SYNTAX: >> mainui

% AUTHORS  : Daniel Johansson & Peter Comnell
% DATE     : 09-August-2010
% Revision : 0.01 Alpha 

% Last Modified by GUIDE v2.5 22-Nov-2010 02:52:27

% 110428 PA SEAlab_v0p0
%           Changed dirpath = '/' to dirpath = filesep; to find the directory separator for the platform


    % Disable warnings for: not used functions and not used input arguments.
    %#ok<*INUSD,*DEFNU,*INUSL>

    %% Begin initialization code - DO NOT EDIT
    gui_Singleton = 1;
    gui_State = struct('gui_Name',       mfilename, ...
                       'gui_Singleton',  gui_Singleton, ...
                       'gui_OpeningFcn', @mainui_OpeningFcn, ...
                       'gui_OutputFcn',  @mainui_OutputFcn, ...
                       'gui_LayoutFcn',  [] , ...
                       'gui_Callback',   []);
    if nargin && ischar(varargin{1})
        gui_State.gui_Callback = str2func(varargin{1});
    end
    if nargout
        [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
    else
        gui_mainfcn(gui_State, varargin{:});
    end
    %% End initialization code - DO NOT EDIT

function mainui_OpeningFcn(hObject, eventdata, handles, varargin)
% Executes just before mainui is made visible.
    handles.output = hObject; % Choose default command line output for mainui   
    guidata(hObject, handles); % Update handles structure
%%

function varargout = mainui_OutputFcn(hObject, eventdata, handles)
% Outputs from this function are returned to the command line.
    varargout{1} = handles.output; % Get default command line output from handles structure
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CREATE FUNCTIONS                                              %%%
%%% - Functions that are executed when the uicontrols are created %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Menus %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Add/del subsystem/connetion panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_addcon_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
%%

function pop_addsubs_CreateFcn(hObject, eventdata, handles)
% Pop-up menu that shows the different types of subsystems availible for
% calculations.
%  Needed Files:      temp\tempdata.mat (Created when main.m is runned)
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    subs_types = cell(length(data.subtypes),1);
    for ii = 1:length(data.subtypes)
        subs_types{ii} = data.subtypes(ii).name;
    end
    set(hObject,'String',subs_types);
%%

function pop_delsubs_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    if data.numss
        set(hObject,'String',num2cell(1:data.numss)')
    else
        set(hObject,'String','N/A')
    end
%%

function pop_delcon_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    if data.numcon
        set(hObject,'String',num2cell(1:data.numcon)')
    else
        set(hObject,'String','N/A')
    end
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Subsystem properties panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_subs_h_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function etxt_subs_b_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function pop_subsnr_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    if data.numss
        set(hObject,'String',num2cell(1:data.numss)')
    else
        set(hObject,'String','N/A')
    end
%%

function etxt_substhickness_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function pop_subsmat_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load physicalproperties.mat solids
    set(hObject,'String',solids.name)
%%

function etxt_subs_d_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function etxt_subslineardamp_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function pop_subspredefdamp_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
%%

function etxt_subsarea_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Connection properties panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function pop_conangle_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function btn_conpropok_CreateFcn(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);
%%

function pop_connr_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    if data.numcon
        set(hObject,'String',num2cell(1:data.numcon)')
    else
        set(hObject,'String','N/A')
    end
%%

function etxt_conlength_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function etxt_plateang_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function etxt_conarea_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

% function pop_contype_CreateFcn(hObject, eventdata, handles)
% %
%     % If the current operating system is a PC the pop-up menu controls is given a white background color.
%     if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
%         set(hObject,'BackgroundColor','white');
%     end
%     load tempdata.mat data
%     contypes = cell(length(data.contypes),1);
%     for ii = 1:length(data.contypes)
%         contypes{ii} = data.contypes(ii).name;
%     end
%     set(hObject,'String',contypes)
% %%

function etxt_numangles_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Input power panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_input_linear_s_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function etxt_input_linear_b_CreateFcn(hObject, eventdata, handles)
%
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

function btn_input_ok_CreateFcn(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);
%%

function pop_input_subsnr_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load tempdata.mat data
    if data.numss
        set(hObject,'String',num2cell(1:data.numss)')
    else
        set(hObject,'String','N/A')
    end
%%

% function pop_input_predef_CreateFcn(hObject, eventdata, handles)
% %
%     % If the current operating system is a PC the pop-up menu controls is given a white background color.
%     if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
%         set(hObject,'BackgroundColor','white');
%     end
%     handles = guidata(hObject); % Get handles
%     set(hObject,'Enable','off')
%     guidata(hObject, handles);
%%

function etxt_input_linear_l_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Visible','off')
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Frequency spectra panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function pop_freqoctstart_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load frequencies froct
    handles = guidata(hObject); % Get handles
    set(hObject,'String',froct);
    set(hObject,'Enable','on')
    guidata(hObject, handles);
%%

function pop_freqoctend_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load frequencies froct
    handles = guidata(hObject); % Get handles
    set(hObject,'String',froct);
    set(hObject,'Enable','on')
    guidata(hObject, handles);

function pop_freq13octstart_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load frequencies fr13oct
    handles = guidata(hObject); % Get handles
    set(hObject,'String',fr13oct);
    set(hObject,'Enable','off')
    guidata(hObject, handles);

function pop_freq13octend_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the pop-up menu controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    load frequencies fr13oct
    handles = guidata(hObject); % Get handles
    set(hObject,'String',fr13oct);
    set(hObject,'Enable','off')
    guidata(hObject, handles);

function etxt_freqlinearstart_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);

function etxt_freqlinearend_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);
%%

function etxt_freqlinearstep_CreateFcn(hObject, eventdata, handles)
%
    % If the current operating system is a PC the textbox controls is given a white background color.
    if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
        set(hObject,'BackgroundColor','white');
    end
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Axes %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function axes_system_CreateFcn(hObject, eventdata, handles)
%
    axis([0 100 0 70]), hold on
%%

function axes_display_CreateFcn(hObject, eventdata, handles)
%
    load tempdata.mat data
    axis([0 100 0 24]), hold on
    for ii = 1:length(data.subtypes)
        switch ii
            case 1, x = 2; y = 2;
            case 2, x = 2; y = 11;
            case 3, x = 32; y = 2;
            case 4, x = 32; y = 11;
            case 5, x = 62; y = 2;
            case 6, x = 62; y = 11;
        end
        image([x x+6],[y+9 y],data.subtypes(ii).value)
        text(x+8,y+4,data.subtypes(ii).name)
    end
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Calculation/Result buttons %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btn_results_CreateFcn(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    set(hObject,'Enable','off')
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Progress panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the Error panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Create functions for the show panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CALLBACK FUNCTIONS                                             %%%
%%% - Functions that are executed when their uicontrols are called %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Menus %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function menu_file_Callback(hObject, eventdata, handles)
%%

function menu_userdef_Callback(hObject, eventdata, handles)
%%

function menu_results_Callback(hObject, eventdata, handles)
%%

function menu_results_modden_Callback(hObject, eventdata, handles)
%%

function menu_results_nummod_Callback(hObject, eventdata, handles)
%%

function menu_results_engunits_Callback(hObject, eventdata, handles)
%%

function menu_results_energy_Callback(hObject, eventdata, handles)
%%

function menu_results_clf_Callback(hObject, eventdata, handles)
%%

function manu_userdef_mat_Callback(hObject, eventdata, handles)
%%

function manu_calc_Callback(hObject, eventdata, handles)
%%

function manu_userdef_power_Callback(hObject, eventdata, handles)
%%

function menu_file_new_Callback(hObject, eventdata, handles)
%%

function menu_file_open_Callback(hObject, eventdata, handles)
%%

function menu_file_save_Callback(hObject, eventdata, handles)
%
% (If you are running win XP/Vista and get the error: "Unable to write to
% file, permission denied". Set your users write/modification permissions in
% the security panel of the directory.)
    handles = guidata(hObject); % Get handles.
    data = getappdata(mainui,'data'); % get data.
    if ~isempty(data.currentfile) % If current file is already set, rewrite data.
        save(data.currentfile,'data')
    else % If current file is not set, select where to save your data.
        [file_name path_name success] = uiputfile('*.mat', 'Save as');
        if success % Save data only if user pressed the 'ok' button.
            data.currentfile = [path_name file_name]; % Set current file.
            save(data.currentfile,'data') % Save the data to the file
            set(handles.mainfig,'Name',['mainui (' data.currentfile ')']) % Set title of the mainui so the current file is shown.
        end
    end
    setappdata(mainui,'data',data) % set data.
    guidata(hObject, handles); % set handles.
%%

function menu_file_exit_Callback(hObject, eventdata, handles)
%
    close all
%%

function menu_help_Callback(hObject, eventdata, handles)
%%

function menu_help_about_Callback(hObject, eventdata, handles)
%%

function menu_help_releasenotes_Callback(hObject, eventdata, handles)
%%

function menu_help_userguide_Callback(hObject, eventdata, handles)
%%

function menu_help_webpage_Callback(hObject, eventdata, handles)
%%

function menu_file_close_Callback(hObject, eventdata, handles)
%
    close('mainui')
%%

function menu_file_saveas_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    [file_name path_name success] = uiputfile('*.mat', 'Save as');
    if success
        data.currentfile = [path_name file_name];
        save(data.currentfile,'data')
        set(handles.mainfig,'Name',['mainui (' data.currentfile ')'])
    end
    setappdata(mainui,'data',data)
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Add/del subsystem/connetion panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_addcon_Callback(hObject, eventdata, handles)
%%

function pop_addsubs_Callback(hObject, eventdata, handles)
%%

function btn_delcon_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    set(hObject,'Interruptible','off');
    del_nr = get(handles.pop_delcon,'Value');
    del_string = get(handles.pop_delcon,'String');
    if strcmp(del_string(del_nr),'N/A')
        set(handles.txt_error2,'String','No connections to delete');
        guidata(hObject, handles);
        return
    end
    if data.numcon == 1
        data.connections.subsystems = [];
        data.numcon = 0;
        setappdata(mainui,'data',data);
        guidata(hObject, handles);
        update_popmenus(mainui)
        update_axes(mainui)
        return
    end
    % temp_connections(1:(data.numcon-1)) = struct('subsystems',[],'type',[],'values',[],'properties_saved',[]);
    for ii = 1:data.numcon
        if ii < del_nr
            temp_connections(ii) = data.connections(ii);
        else
            if ii < data.numcon
                temp_connections(ii) = data.connections(ii+1);
            end
        end
    end
    data.connections = temp_connections;
    data.numcon = data.numcon-1;
    setappdata(mainui,'data',data);
    set(handles.pop_delcon,'Value',1);
    guidata(hObject, handles);
    update_popmenus(mainui)
    update_axes(mainui)
%%

function btn_addcon_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    set(hObject,'Interruptible','off');
    if data.numss<2
        set(handles.txt_error2,'String','Need to create atleast two subsystems before trying to connect anything');
        return
    end
    cons = str2double(get(handles.etxt_addcon,'String')); % ?ndra till en popup menu som startar fr?n 2, slutar med 'more' d?r man f?r upp en ruta att skriva in
    % vid 'more' kolla ?ven s? att man skriver in en siffra och att den
    % inte ?r 1
    [x,y] = ginput(cons);
    found_ss = 0;
    for jj = 1:cons
        for ii = 1:data.numss
            if (data.subsystems(ii).coord(1)-4 < x(jj) && x(jj) < data.subsystems(ii).coord(1)+4) && (data.subsystems(ii).coord(2)-4 < y(jj) && y(jj) < data.subsystems(ii).coord(2)+4)
                found_ss = found_ss + 1;
                p(jj) = ii;
            end
        end
    end
    if ~(found_ss == cons)
        set(handles.txt_error2,'String','Did not find all the subsystems to connect');
        return
    end
    if length(p) ~= length(unique(p))
        set(handles.txt_error2,'String','Cant connect a subsystem to itself');
        return
    end
    if data.numcon
        for ii = 1:data.numcon
            if length(p) == length(data.connections(ii).subsystems)
                if sort(p) == sort(data.connections(ii).subsystems)
                    % kolla ?ven f?r connections som inte inneh?ller lika m?nga subsystem
                    set(handles.txt_error2,'String','Connection already exists');
                    return
                end
            end
        end
    end
    for ii = 1:cons
        types{ii} = data.subsystems(p(ii)).type;
    end
    switch cons
        case 2
            if (strcmp(types{1},'plate') && strcmp(types{2},'plate'))
                data.connections(data.numcon+1).type = 'plates';
                data.connections(data.numcon+1).values.angles(1) = 0;
                data.connections(data.numcon+1).angles_saved = 0;
            elseif (strcmp(types{1},'cavity') && strcmp(types{2},'plate'))
                data.connections(data.numcon+1).plate_nr = p(2);
                data.connections(data.numcon+1).cavity_nr = p(1);
                data.connections(data.numcon+1).type = 'plate cavity';
            elseif (strcmp(types{1},'plate') && strcmp(types{2},'cavity'))
                data.connections(data.numcon+1).plate_nr = p(1);
                data.connections(data.numcon+1).cavity_nr = p(2);
                data.connections(data.numcon+1).type = 'plate cavity';
            elseif ((strcmp(types{1},'cavity') && strcmp(types{2},'semiinfinitefluid')) || (strcmp(types{1},'semiinfinitefluid') && strcmp(types{2},'cavity')))
                data.connections(data.numcon+1).type = 'cavity semiinfinite fluid';
            elseif ((strcmp(types{1},'plate') && strcmp(types{2},'semiinfinitefluid')) || (strcmp(types{1},'semiinfinitefluid') && strcmp(types{2},'plate')))
                data.connections(data.numcon+1).type = 'plate semiinfinite fluid';
            else
                set(handles.txt_error2,'String','Not a valid connection');
                return
            end
        case 3
            if (strcmp(types{1},'cavity') && strcmp(types{2},'plate') && strcmp(types{3},'cavity'))
                data.connections(data.numcon+1).plate_nr = p(2);
                data.connections(data.numcon+1).cavity_nr = [p(1) p(3)];
                data.connections(data.numcon+1).type = 'leaf wall';
            elseif (strcmp(types{1},'plate') && strcmp(types{2},'plate') && strcmp(types{3},'plate'))
                data.connections(data.numcon+1).type = 'plates';
                data.connections(data.numcon+1).values.angles(1) = 0;
                data.connections(data.numcon+1).angles_saved = 0;
            else
                set(handles.txt_error2,'String','Not a valid connection');
                return
            end
        case 5
            if (strcmp(types{1},'cavity') && strcmp(types{2},'plate') && strcmp(types{3},'cavity') && strcmp(types{4},'plate') && strcmp(types{1},'cavity'))
                data.connections(data.numcon+1).type = 'double wall';
            elseif (strcmp(types{1},'plate') && strcmp(types{2},'plate') && strcmp(types{3},'plate') && strcmp(types{4},'plate') && strcmp(types{1},'plate'))
                data.connections(data.numcon+1).type = 'plates';
                data.connections(data.numcon+1).values.angles(1) = 0;
                data.connections(data.numcon+1).angles_saved = 0;
            else
                set(handles.txt_error2,'String','Not a valid connection');
                return
            end
        otherwise
            for ii = 1:cons
                if ~strcmp(types{ii},'plate')
                    set(handles.txt_error2,'String','Not a valid connection');
                    return
                end
            end
            data.connections(data.numcon+1).type = 'plates';
            data.connections(data.numcon+1).values.angles(1) = 0;
            data.connections(data.numcon+1).angles_saved = 0;
    end
    p_x = [];
    p_y = [];
    for ii=1:cons
        p_x = [p_x data.subsystems(p(ii)).coord(1)]; 
        p_y = [p_y data.subsystems(p(ii)).coord(2)];
    end
    mid_coord = [(sum(p_x)/cons) (sum(p_y)/cons)];
    data.numcon = data.numcon + 1;
    data.connections(data.numcon).centre_coord = mid_coord;
    data.connections(data.numcon).types = types;
    if cons > 2
        for ii = 1:cons
            line([p_x(ii) mid_coord(1)],[p_y(ii) mid_coord(2)]), hold on
        end
    elseif cons == 2
        line([data.subsystems(p(1)).coord(1) data.subsystems(p(2)).coord(1)],[data.subsystems(p(1)).coord(2) data.subsystems(p(2)).coord(2)]), hold on
    end
    text(mid_coord(1),mid_coord(2),num2str(data.numcon),'BackgroundColor','b','Color','w')
    data.connections(data.numcon).properties_saved = 0;
    data.connections(data.numcon).subsystems = p;
    %     data.connections(data.numcon).values = struct('tau',[],'length',[],'area',[],'con_angle',[],'wave_angles',[])
    setappdata(mainui,'data',data)
    guidata(hObject, handles);
    update_popmenus(mainui)
%%

function btn_delsubs_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    set(hObject,'Interruptible','off');
    data = getappdata(mainui,'data');
    del_nr = get(handles.pop_delsubs,'Value');
    del_string = get(handles.pop_delsubs,'String');
    if strcmp(del_string(del_nr),'N/A')
        set(handles.txt_error2,'String','No subsystem to delete');
        guidata(hObject, handles);
        return
    end
    if data.numcon
        for ii = 1:data.numcon
            find(data.connections(ii).subsystems == del_nr)
            set(handles.txt_error2,'String','Subsystem has atleast one connection, delete the corresponding connections first');
            return
        end
    end
    if data.numss == 1
        data.subsystems = [];
        data.numss = 0;
        setappdata(mainui,'data',data)
        guidata(hObject, handles);
        update_popmenus(mainui)
        update_axes(mainui)
        return
    end
    % temp_subs(1:(data.numss-1)) = struct('type',[],'coord',[],'properties_saved',[],'properties',[]);
    for ii = 1:data.numss
        if ii < del_nr
            temp_subs(ii) = data.subsystems(ii);
        else
            if ii < data.numss
                temp_subs(ii) = data.subsystems(ii+1);
            end
        end
    end
    data.subsystems = temp_subs;
    data.numss = data.numss-1;
    setappdata(mainui,'data',data)
    set(handles.pop_delsubs,'Value',1);
    guidata(hObject, handles);
    update_popmenus(mainui)
    update_axes(mainui)
%%

function pop_delcon_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject);
    guidata(hObject, handles);
%%

function pop_delsubs_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject);
    guidata(hObject, handles);
%%

function btn_addsubs_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    set(hObject,'Interruptible','off');
    % error if [x,y] not inside the axes
    [x,y] = ginput(1);
    data.numss = data.numss+1;
    subsvalue = get(handles.pop_addsubs,'Value');
    data.subsystems(data.numss).type = data.subtypes(subsvalue).name;
    data.subsystems(data.numss).coord = [x y];
    data.subsystems(data.numss).properties_saved = 0;
    data.subsystems(data.numss).input_power_saved = 0;
    % data.subsystems(data.numss).values = struct('damping',[],'thickness',[],'material',[],'E',[],'poi',[],'D',[],'material_type',[])
    hold on
    data.subsystems(data.numss).img_handles = image([x-4 x+4],[y+4 y-4],data.subtypes(subsvalue).value);
    text(x+2,y+4,num2str(data.numss),'BackgroundColor','k','Color','w')
    eval(['tag_name = ' char(39) ' ' data.subsystems(data.numss).type num2str(data.numss) char(39) ';'])
    set(data.subsystems(data.numss).img_handles,'Tag',tag_name)
    set(data.subsystems(data.numss).img_handles,'buttondownfcn',@img_click)
    setappdata(mainui,'data',data)
    % drawimage(data.subsystems(data.numss).type,data.numss,x,y)
    update_popmenus(mainui)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Subsystem properties panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_subs_b_Callback(hObject, eventdata, handles)
%%

function etxt_subs_h_Callback(hObject, eventdata, handles)
%%

function btn_subsprop_ok_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    set(hObject,'Interruptible','off');
    subs_nr = get(handles.pop_subsnr,'Value');
    if ~data.numss
        return
    end
    if (~strcmp(data.subsystems(subs_nr).type,'semiinfinitefluid') && isempty(get(handles.etxt_subslineardamp,'String')))
        set(handles.txt_error2,'String','Subsystem inner damping losses not set')
        return
    end
    switch data.subsystems(subs_nr).type
        case 'cavity'
            if (isempty(get(handles.etxt_subs_d,'String')) ||isempty(get(handles.etxt_subs_b,'String')) || isempty(get(handles.etxt_subs_h,'String')))
                set(handles.txt_error2,'String','Cavity dimensions not set')
                return
            end
            data.subsystems(subs_nr).values.material = get(handles.pop_subsmat,'Value');
            data.subsystems(subs_nr).values.dim = [str2double(get(handles.etxt_subs_b,'String')) str2double(get(handles.etxt_subs_h,'String')) str2double(get(handles.etxt_subs_d,'String'))];
            data.subsystems(subs_nr).values.volume =data.subsystems(subs_nr).values.dim(1)*data.subsystems(subs_nr).values.dim(2)*data.subsystems(subs_nr).values.dim(3);
            if get(handles.rbtn_subslineardamp,'Value')
                data.subsystems(subs_nr).values.damping.b = str2double(get(handles.etxt_subslineardamp,'String'));
                data.subsystems(subs_nr).values.damping.l = str2double(get(handles.etxt_subslineardamp,'String'));
                data.subsystems(subs_nr).values.damping.s = str2double(get(handles.etxt_subslineardamp,'String'));
            end
        case 'plate'
            if isempty(get(handles.etxt_substhickness,'String'))
                set(handles.txt_error2,'String','Plate thickness not set')
                return
            elseif isempty(get(handles.etxt_subs_b,'String'))
                set(handles.txt_error2,'String','Plate width not set')
                return
            elseif isempty(get(handles.etxt_subs_h,'String'))
                set(handles.txt_error2,'String','Plate length not set')
                return
            end
            data.subsystems(subs_nr).values.material = get(handles.pop_subsmat,'Value');
            data.subsystems(subs_nr).values.thickness = str2double(get(handles.etxt_substhickness,'String'))/1000;
            if get(handles.rbtn_subslineardamp,'Value')
                data.subsystems(subs_nr).values.damping.b = str2double(get(handles.etxt_subslineardamp,'String'));
                data.subsystems(subs_nr).values.damping.l = str2double(get(handles.etxt_subslineardamp,'String'));
                data.subsystems(subs_nr).values.damping.s = str2double(get(handles.etxt_subslineardamp,'String'));
                data.subsystems(subs_nr).values.dim = [str2double(get(handles.etxt_subs_b,'String')) str2double(get(handles.etxt_subs_h,'String'))];
            end
        case 'semiinfinitefluid'
            data.subsystems(subs_nr).values.material = get(handles.pop_subsmat,'Value');
    end
    data.subsystems(subs_nr).properties_saved = 1;
    setappdata(mainui,'data',data)
    guidata(hObject, handles);
%%

function pop_subsnr_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    subs_nr = get(hObject,'Value');
    set(hObject,'Interruptible','off')
    if strcmp(get(hObject,'String'),'N/A')
%     if ~isnumeric(subs_nr)
        return
    end
    load physicalproperties solids fluids
    set(handles.pop_subsmat,'Value',1)
    set(handles.rbtn_subslineardamp,'Value',1)
        set(handles.txt_subsmat,'Visible','on')
        set(handles.pop_subsmat,'Visible','on')
        set(handles.txt_subsloss,'Visible','on')
        set(handles.btng_subslosstype,'Visible','on')
        set(handles.etxt_subslineardamp,'Visible','on')
        set(handles.txt_subslineardamp,'Visible','on')
        set(handles.btn_freq_set,'Visible','off')
        set(handles.btn_subsprop_ok,'Visible','on')
    switch data.subsystems(subs_nr).type
        case 'cavity'
            set(handles.pop_subsmat,'String',fluids.name)
            set(handles.txt_substhickness,'Visible','off')
            set(handles.etxt_substhickness,'Visible','off')
            set(handles.txt_subsmm,'Visible','off')
            set(handles.txt_subsarea,'Visible','off')
            set(handles.etxt_subsarea,'Visible','off')
            set(handles.txt_subsm2,'Visible','off')
            set(handles.txt_subs_d,'Visible','on')
            set(handles.etxt_subs_d,'Visible','on')
            set(handles.txt_subs_d2,'Visible','on')
            set(handles.txt_subs_b,'Visible','on')
            set(handles.etxt_subs_b,'Visible','on')
            set(handles.txt_subs_b2,'Visible','on')
            set(handles.txt_subs_h,'Visible','on')
            set(handles.txt_subs_hh,'Visible','off')
            set(handles.etxt_subs_h,'Visible','on')
            set(handles.txt_subs_h2,'Visible','on')
        case 'plate'
            set(handles.pop_subsmat,'String',solids.name)
            set(handles.txt_substhickness,'Visible','on')
            set(handles.etxt_substhickness,'Visible','on')
            set(handles.txt_subsmm,'Visible','on')
            set(handles.txt_subsarea,'Visible','on')
            set(handles.etxt_subsarea,'Visible','on')
            set(handles.txt_subsm2,'Visible','on')
            set(handles.txt_subs_d,'Visible','off')
            set(handles.etxt_subs_d,'Visible','off')
            set(handles.txt_subs_d2,'Visible','off')
            set(handles.txt_subs_b,'Visible','on')
            set(handles.etxt_subs_b,'Visible','on')
            set(handles.txt_subs_b2,'Visible','on')
            set(handles.txt_subs_h,'Visible','off')
            set(handles.txt_subs_hh,'Visible','on')
            set(handles.etxt_subs_h,'Visible','on')
            set(handles.txt_subs_h2,'Visible','on')
        case 'semiinfinitefluid'
            set(handles.pop_subsmat,'String',fluids.name)
            set(handles.txt_substhickness,'Visible','off')
            set(handles.etxt_substhickness,'Visible','off')
            set(handles.txt_subsmm,'Visible','off')
            set(handles.txt_subsarea,'Visible','off')
            set(handles.etxt_subsarea,'Visible','off')
            set(handles.txt_subsm2,'Visible','off')
            set(handles.txt_subs_d,'Visible','off')
            set(handles.etxt_subs_d,'Visible','off')
            set(handles.txt_subs_d2,'Visible','off')
            set(handles.txt_subs_b,'Visible','off')
            set(handles.etxt_subs_b,'Visible','off')
            set(handles.txt_subs_b2,'Visible','off')
            set(handles.txt_subs_h,'Visible','off')
            set(handles.txt_subs_hh,'Visible','off')
            set(handles.etxt_subs_h,'Visible','off')
            set(handles.txt_subs_h2,'Visible','off')
            set(handles.txt_subsloss,'Visible','off')
            set(handles.btng_subslosstype,'Visible','off')
            set(handles.etxt_subslineardamp,'Visible','off')
            set(handles.txt_subslineardamp,'Visible','off')
    end
    

    
    
    
    
    guidata(hObject, handles);
%%

function rbtn_subslineardamp_Callback(hObject, eventdata, handles)
%%

function rbtn_freqdamp_Callback(hObject, eventdata, handles)
%%

function pop_subspredefdamp_Callback(hObject, eventdata, handles)
%%

function etxt_substhickness_Callback(hObject, eventdata, handles)
%%

function etxt_subslineardamp_Callback(hObject, eventdata, handles)
%%

function etxt_subs_d_Callback(hObject, eventdata, handles)
%%

function pop_subsmat_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject);
    guidata(hObject, handles);
%%

function etxt_subsarea_Callback(hObject, eventdata, handles)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Connection properties panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btn_conprop_angle_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
%     con_string_all = get(handles.pop_conangle,'String');
    current = handles.current;
    con_value = get(handles.pop_conangle,'Value');
%     con_string = con_string_all(con_value);
%     ss1 = str2double(con_string(1:(find(con_string == '-')-2)));
%     ss2 = str2double(con_string((find(con_string == '-')+2):length(con_string)));
    
    data.connections(current).values.angles(con_value+1) = str2double(get(handles.etxt_plateang,'String'));
    if length(data.connections(current).values.angles) == length(data.connections(current).subsystems)
        data.connections(current).angles_saved = 1;
        set(handles.btn_conpropok,'Enable','on')
    end
    set(handles.txt_conangles,'Visible','on')
    set(handles.txt_conang,'Visible','on')
    set(handles.txt_plateangdeg,'Visible','on')
    set(handles.txt_conlength,'Visible','on')
    set(handles.txt_conlengthm,'Visible','on')
    guidata(hObject, handles);
    setappdata(mainui,'data',data)
%%    

function pop_conangle_Callback(hObject, eventdata, handles)
%%

function pop_connr_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    handles.current = 1;
    set(handles.pop_conangle,'Value',1)
    con_nr = get(hObject,'Value');
    set(hObject,'Interruptible','off')
    if ~isnumeric(con_nr)
        return
    end
    if strcmp(data.connections(con_nr).type,'plates')
        set(handles.txt_conangles,'Visible','on')
        set(handles.txt_conang,'Visible','on')
        set(handles.txt_conarea,'Visible','off')
        set(handles.txt_conaream2,'Visible','off')
        set(handles.txt_plateangdeg,'Visible','on')
        set(handles.txt_conlength,'Visible','on')
        set(handles.txt_conlengthm,'Visible','on')
        set(handles.etxt_conlength,'Visible','on')
        set(handles.etxt_plateang,'Visible','on')
        set(handles.pop_conangle,'Visible','on')
        set(handles.btn_conprop_angle,'Visible','on')
        set(handles.etxt_conarea,'Visible','off')
        set(handles.etxt_numangles,'Visible','on')
        if (length(data.connections(con_nr).values.angles) == length(data.connections(con_nr).subsystems))
            set(handles.btn_conpropok,'Enable','on')
        else
            set(handles.btn_conpropok,'Enable','off')
        end
        for ii = 2:length(data.connections(con_nr).subsystems);
            con_string{ii-1} = [num2str(data.connections(con_nr).subsystems(1)) ' - ' num2str(data.connections(con_nr).subsystems(ii))];
        end
        set(handles.pop_conangle,'String',con_string)
    elseif (strcmp(data.connections(con_nr).type,'leaf wall') || strcmp(data.connections(con_nr).type,'double wall') || strcmp(data.connections(con_nr).type,'plate cavity') || strcmp(data.connections(con_nr).type,'plate semiinfinite fluid') || strcmp(data.connections(con_nr).type,'cavity semiinfinite fluid'))
        set(handles.txt_conarea,'Visible','on')
        set(handles.txt_conaream2,'Visible','on')
        set(handles.etxt_conlength,'Visible','off')
        set(handles.pop_conangle,'Visible','off')
        set(handles.btn_conprop_angle,'Visible','off')
        set(handles.etxt_plateang,'Visible','off')
        set(handles.etxt_conarea,'Visible','on')
        set(handles.etxt_numangles,'Visible','off')
        set(handles.btn_conpropok,'Enable','on')
        set(handles.txt_conlength,'Visible','off')
        set(handles.txt_conlengthm,'Visible','off')
        set(handles.txt_conangles,'Visible','off')
        set(handles.txt_conang,'Visible','off')
        set(handles.txt_plateangdeg,'Visible','off')
    end
    handles.current = con_nr;
    guidata(hObject, handles);
%%

function etxt_conlength_Callback(hObject, eventdata, handles)
%%

function btn_conpropok_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    con_nr = get(handles.pop_connr,'Value');
    if ~data.numcon
        return
    end
    if strcmp(data.connections(con_nr).type,'plates')
        if isempty(get(handles.etxt_conlength,'String'))
            set(handles.txt_error2,'String','Connection length not set')
            return
        elseif isempty(get(handles.etxt_numangles,'String'))
            set(handles.txt_error2,'String','Average of number of incident angles not set')
            return
        end
        data.connections(con_nr).values.length = str2double(get(handles.etxt_conlength,'String'));
%         data.connections(con_nr).values.angles = str2double(get(handles.etxt_plateang,'String'));
        data.connections(con_nr).values.num_angles = str2double(get(handles.etxt_numangles,'String'));
    elseif (strcmp(data.connections(con_nr).type,'leaf wall') || strcmp(data.connections(con_nr).type,'double wall') || strcmp(data.connections(con_nr).type,'plate cavity') || strcmp(data.connections(con_nr).type,'plate semiinfinite fluid') || strcmp(data.connections(con_nr).type,'cavity semiinfinite fluid'))
        if isempty(get(handles.etxt_conarea,'String'))
            set(handles.txt_error2,'String','Connection area not set')
            return
        end
        data.connections(con_nr).values.area = str2double(get(handles.etxt_conarea,'String'));
    end
    
    
    
    
    
%     nr_plates = 0;
%     nr_cavities = 0;
%     nr_rooms = 0;
%     nr_semi = 0;
%     for ii = 1:length(data.connections(con_nr).types)
%         switch data.connections(con_nr).types{ii}
%             case 'plate', nr_plates = nr_plates +1;
%             case 'cavity', nr_cavities = nr_cavities +1;
%             case 'room', nr_rooms = nr_rooms +1;
%             case 'semiinfinitefluid', nr_semi = nr_semi +1;
%         end
%     end
%     
%     if nr_plates
%         if nr_plates == length(data.connections(con_nr).types)
%             if isempty(get(handles.etxt_conlength,'String'))
%                 set(handles.txt_error2,'String','Connection length not set')
%                 return
%             elseif isempty(get(handles.etxt_plateang,'String'))
%                 set(handles.txt_error2,'String','Plate connection angle not set')
%                 return
%             end
%             data.connections(con_nr).values.length = str2double(get(handles.etxt_conlength,'String'));
% %             data.connections(con_nr).values.angles = str2double(get(handles.etxt_plateang,'String'));
%             data.connections(con_nr).values.num_angles = str2double(get(handles.etxt_numangles,'String'));
%         elseif (nr_cavities || nr_rooms || nr_semi)
%             set(handles.etxt_conlength,'Enable','off')
%             set(handles.etxt_plateang,'Enable','off')
%             set(handles.etxt_conarea,'Enable','on')
%             set(handles.etxt_conarea,'Enable','on')
%             set(handles.etxt_numangles,'Enable','off')
%         end
%     elseif ((nr_cavities && (nr_rooms || nr_semi)) || nr_cavities == 2)
%             set(handles.etxt_conlength,'Enable','off')
%             set(handles.etxt_plateang,'Enable','off')
%             set(handles.etxt_conarea,'Enable','off')
%             set(handles.etxt_conarea,'Enable','on')
%             set(handles.etxt_numangles,'Enable','off')
%     end
    
%     switch data.connections(con_nr).types
%         case 'plate_plate'
%             if isempty(get(handles.etxt_conlength,'String'))
%                 set(handles.txt_error2,'String','Connection length not set')
%                 return
%             elseif isempty(get(handles.etxt_plateang,'String'))
%                 set(handles.txt_error2,'String','Plate connection angle not set')
%                 return
%             end
%             data.connections(con_nr).values.length = str2double(get(handles.etxt_conlength,'String'));
%             data.connections(con_nr).values.angles = str2double(get(handles.etxt_plateang,'String'));
            
            
            
%             data.connections(con_nr).values.num_angles = str2double(get(handles.etxt_numangles,'String'));
%         case 'cavity_cavity'
%             % ?
%         case 'plate_cavity'
%              if isempty(get(handles.etxt_conarea,'String'))
%                 set(handles.txt_error2,'String','Connection area not set')
%                 return
%              end
%             data.connections(con_nr).values.area = str2double(get(handles.etxt_conarea,'String'));
%         case 'plate_semiinfinitefluid'
%              if isempty(get(handles.etxt_conarea,'String'))
%                 set(handles.txt_error2,'String','Connection area not set')
%                 return
%              end
%             data.connections(con_nr).values.area = str2double(get(handles.etxt_conarea,'String'));
%         case 'cavity_semiinfinitefluid'
%         % ?

    data.connections(con_nr).properties_saved = 1;
    setappdata(mainui,'data',data)
    guidata(hObject, handles);
%%

function etxt_conarea_Callback(hObject, eventdata, handles)
%%

function etxt_plateang_Callback(hObject, eventdata, handles)
%%

function etxt_numangles_Callback(hObject, eventdata, handles)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Input power panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function etxt_input_linear_s_Callback(hObject, eventdata, handles)
set(hObject,'Visible','off')
%%

function etxt_input_linear_b_Callback(hObject, eventdata, handles)
%%

function pop_input_subsnr_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    subs_nr = get(hObject,'Value');
    if ~isnumeric(subs_nr)
        return
    end
    if strcmp(data.subsystems(subs_nr).type,'plate')
        set(handles.etxt_input_linear_b,'Visible','on')
        set(handles.etxt_input_linear_l,'Visible','on')
        set(handles.etxt_input_linear_s,'Visible','on')
        set(handles.txt_input_lin_b1,'Visible','on')
        set(handles.txt_input_lin_b2,'Visible','on')
        set(handles.txt_input_lin_l1,'Visible','on')
        set(handles.txt_input_lin_l2,'Visible','on')
        set(handles.txt_input_lin_s1,'Visible','on')
        set(handles.txt_input_lin_s2,'Visible','on')
    elseif strcmp(data.subsystems(subs_nr).type,'cavity')
        set(handles.etxt_input_linear_b,'Visible','off')
        set(handles.etxt_input_linear_l,'Visible','on')
        set(handles.etxt_input_linear_s,'Visible','off')
        set(handles.txt_input_lin_b1,'Visible','off')
        set(handles.txt_input_lin_b2,'Visible','off')
        set(handles.txt_input_lin_l1,'Visible','on')
        set(handles.txt_input_lin_l2,'Visible','on')
        set(handles.txt_input_lin_s1,'Visible','off')
        set(handles.txt_input_lin_s2,'Visible','off')
    elseif strcmp(data.subsystems(subs_nr).type,'semiinfinitefluid')
        set(handles.etxt_input_linear_b,'Visible','off')
        set(handles.etxt_input_linear_l,'Visible','off')
        set(handles.etxt_input_linear_s,'Visible','off')
        set(handles.txt_input_lin_b1,'Visible','off')
        set(handles.txt_input_lin_b2,'Visible','off')
        set(handles.txt_input_lin_l1,'Visible','off')
        set(handles.txt_input_lin_l2,'Visible','off')
        set(handles.txt_input_lin_s1,'Visible','off')
        set(handles.txt_input_lin_s2,'Visible','off')
    end
    set(handles.rbtn_input_linear,'Value',1)
    set(handles.btn_exitation,'Visible','off')
    set(handles.btn_input_ok,'Enable','on')
    guidata(hObject, handles);
%%

function btn_input_ok_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    save testar21nov data
    subsnr = get(handles.pop_input_subsnr,'Value');
    if get(handles.rbtn_input_linear,'Value')
        switch data.subsystems(subsnr).type
            case 'plate'
                if (isempty(get(handles.etxt_input_linear_b,'String')) || isempty(get(handles.etxt_input_linear_l,'String')) || isempty(get(handles.etxt_input_linear_s,'String')))
                    set(handles.txt_error2,'String','Input powers not set')
                    return
                end
                data.subsystems(subsnr).values.input_power.type = 'Linear';
                data.subsystems(subsnr).values.input_power.power.b = str2double(get(handles.etxt_input_linear_b,'String'));
                data.subsystems(subsnr).values.input_power.power.l = str2double(get(handles.etxt_input_linear_l,'String'));
                data.subsystems(subsnr).values.input_power.power.s = str2double(get(handles.etxt_input_linear_s,'String'));
            case 'cavity'
                if isempty(get(handles.etxt_input_linear_l,'String'))
                    set(handles.txt_error2,'String','Input powers not set')
                    return
                end
                data.subsystems(subsnr).values.input_power.type = 'Linear';
                data.subsystems(subsnr).values.input_power.power.b = 0;
                data.subsystems(subsnr).values.input_power.power.l = str2double(get(handles.etxt_input_linear_l,'String'));
                data.subsystems(subsnr).values.input_power.power.s = 0;
            case 'semiinfinitefluid'
                data.subsystems(subsnr).values.input_power.power.b = 0;
                data.subsystems(subsnr).values.input_power.power.l = 0;
                data.subsystems(subsnr).values.input_power.power.s = 0;
        end
        data.subsystems(subsnr).input_power_saved = 1;
    end
    setappdata(mainui,'data',data)
    guidata(hObject, handles);
%%

function pop_input_predef_Callback(hObject, eventdata, handles)
%%

function etxt_input_linear_l_Callback(hObject, eventdata, handles)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Frequency spectra panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function rbtn_freqoct_Callback(hObject, eventdata, handles)
%%

function rbtn_freq13oct_Callback(hObject, eventdata, handles)
%%

function rbtn_freqlinear_Callback(hObject, eventdata, handles)
%%

function pop_freqoctstart_Callback(hObject, eventdata, handles)
%%

function pop_freq13octstart_Callback(hObject, eventdata, handles)
%%

function pop_freq13octend_Callback(hObject, eventdata, handles)
%%

function etxt_freqlinearstart_Callback(hObject, eventdata, handles)
%%

function etxt_freqlinearend_Callback(hObject, eventdata, handles)
%%

function etxt_freqlinearstep_Callback(hObject, eventdata, handles)
%%

function pop_freqoctend_Callback(hObject, eventdata, handles)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Axes %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Calculation/Result buttons %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btn_calc_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    handles = guidata(hObject); % Get handles
    for ii = 1:data.numss
        switch data.subsystems(ii).properties_saved
            case 0
                set(handles.txt_error2,'String',['Subsystem ' num2str(ii) 's: properties not saved'])
                return
        end
        switch data.subsystems(ii).input_power_saved
            case 0
                set(handles.txt_error2,'String',['Subsystem ' num2str(ii) 's: input power not set'])
                return
        end
    end
    for ii = 1:data.numcon
        switch data.connections(ii).properties_saved
            case 0
                set(handles.txt_error2,'String',['Connection ' num2str(ii) 's: properties not saved'])
                return
        end
    end
    load frequencies.mat fr13oct froct
    if get(handles.rbtn_freqoct,'Value');
        start_pos = get(handles.pop_freqoctstart,'Value');
        end_pos = get(handles.pop_freqoctend,'Value');
        if start_pos > end_pos
            set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
            return
        end
        data.f = frequency(froct(start_pos),froct(end_pos),'octave');
    elseif get(handles.rbtn_freq13oct,'Value');
        start_pos = get(handles.pop_freq13octstart,'Value');
        end_pos = get(handles.pop_freq13octend,'Value');
        if start_pos > end_pos
            set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
            return
        end
        data.f = frequency(fr13oct(start_pos),fr13oct(end_pos),'13octave');
    elseif get(handles.rbtn_freqlinear,'Value');
        start_freq = str2double(get(handles.etxt_freqlinearstart,'String'));
        end_freq = str2double(get(handles.etxt_freqlinearend,'String'));
        if start_freq > end_freq
            set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
            return
        end
        step = str2double(get(handles.etxt_freqlinearstep,'String'));
        data.f = frequency(start_freq,end_freq,'linear',step);
    end
    for ii = 1:data.numss
        data.subsystems(ii).values = set_subsystem_values(data.subsystems(ii).type,data.subsystems(ii).values);
        if strcmp(data.subsystems(ii).type,'plate')
            data.subsystems(ii).values.k = calc_k(data.subsystems(ii).values,data.f,data.subsystems(ii).type);
            data.subsystems(ii).values.c = calc_c(data.subsystems(ii).values.k,data.f);
            data.subsystems(ii).values.mden = mden_calc(data.f,data.subsystems(ii).values,data.subsystems(ii).type);
        elseif strcmp(data.subsystems(ii).type,'cavity')
            data.subsystems(ii).values.k = calc_k(data.subsystems(ii).values,data.f,data.subsystems(ii).type);
            data.subsystems(ii).values.mden = mden_calc(data.f,data.subsystems(ii).values,data.subsystems(ii).type);
        end
    end
    for ii = 1:data.numcon
        if strcmp(data.connections(ii).type,'plates')
            for jj = 1:length(data.connections(ii).subsystems)
                subsystem_values(jj) = data.subsystems(data.connections(ii).subsystems(jj)).values;
            end
            temp.ss_values = subsystem_values;
            temp.con_values = data.connections(1).values;
            data.connections(ii).tau = tau_plate_plate(data.f,data.connections(ii).values,subsystem_values);
            data.connections(ii).clf = clf_plate_plate(data.f,data.connections(ii),subsystem_values);
        elseif strcmp(data.connections(ii).type,'plate cavity')
            plate_values = data.subsystems(data.connections(ii).plate_nr).values;
            cavity_values = data.subsystems(data.connections(ii).cavity_nr).values;
            plate_clf_tot = 0.02; % = ???
            rad_return = plate_cavity_rad_tau(data.f,plate_values,cavity_values,plate_clf_tot);
            data.connections(ii).tau = rad_return.tau;
            data.connections(ii).radiation_eff = rad_return.rad;
            data.connections(ii).clf = clf_leaf_wall(data.f,plate_values,cavity_values,data.connections(ii));
        elseif strcmp(data.connections(ii).type,'leaf wall')
            plate_values = data.subsystems(data.connections(ii).plate_nr).values;
            cavity_values(1) = data.subsystems(data.connections(ii).cavity_nr(1)).values;
            cavity_values(2) = data.subsystems(data.connections(ii).cavity_nr(2)).values;
            plate_clf_tot = 0.02; % = ???
            rad_return = plate_cavity_rad_tau(data.f,plate_values,cavity_values,plate_clf_tot);
            data.connections(ii).tau = rad_return.tau;
            data.connections(ii).radiation_eff = rad_return.rad;
            data.connections(ii).clf = clf_leaf_wall(data.f,plate_values,cavity_values,data.connections(ii));
        elseif strcmp(data.connections(ii).type,'double wall')
            plate_values(1) = data.subsystems(data.connections(ii).subsystems(2)).values;
            plate_values(2) = data.subsystems(data.connections(ii).subsystems(4)).values;
            cavity_values(1) = data.subsystems(data.connections(ii).subsystems(1)).values;
            cavity_values(2) = data.subsystems(data.connections(ii).subsystems(3)).values;
            cavity_values(3) = data.subsystems(data.connections(ii).subsystems(5)).values;
            data.connections(ii).clf = clf_double_wall(data.f,data.connections(ii).values,plate_values,cavity_values);
        end
        clear subsystem_values plate_values cavity_values;
    end
    data = energy_calc_v0p0(data);
    dirpath = filesep;
    temppath = ['results' dirpath 'last_data.mat'];
    save(temppath,'data')%,'temp')
    set(handles.btn_results,'Enable','on');
    guidata(hObject, handles);
%%

function btn_results_Callback(hObject, eventdata, handles)
%
    data = getappdata(mainui,'data');
    setappdata(resultsui,'data',data);
    resultsui
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Progress panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Error panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Callback functions for the Show panel %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btn_show_Callback(hObject, eventdata, handles)
%%

function cbx_show_subs_Callback(hObject, eventdata, handles)
%%

function cbx_show_con_Callback(hObject, eventdata, handles)
%%

function cbx_show_subsnr_Callback(hObject, eventdata, handles)
%%

function cbx_show_connr_Callback(hObject, eventdata, handles)
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SELECTION CHANGE FUNCTIONS                                   %%%
%%% - Function that are executed when their uicontrol is changed %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btng_freq_SelectionChangeFcn(hObject, eventdata, handles)
    handles = guidata(hObject); % Get handles
    switch get(eventdata.NewValue,'Tag')   % Get Tag of selected object
        case 'rbtn_freqoct' % if frequency spectra = octave band
            set(handles.pop_freqoctstart,'Enable','on');
            set(handles.pop_freqoctend,'Enable','on');
            set(handles.pop_freq13octstart,'Enable','off');
            set(handles.pop_freq13octend,'Enable','off');
            set(handles.etxt_freqlinearstart,'Enable','off');
            set(handles.etxt_freqlinearend,'Enable','off');
            set(handles.etxt_freqlinearstep,'Enable','off');
        case 'rbtn_freq13oct' % if frequency spectra = 1/3-octave band
            set(handles.pop_freqoctstart,'Enable','off');
            set(handles.pop_freqoctend,'Enable','off');
            set(handles.pop_freq13octstart,'Enable','on');
            set(handles.pop_freq13octend,'Enable','on');
            set(handles.etxt_freqlinearstart,'Enable','off');
            set(handles.etxt_freqlinearend,'Enable','off');
            set(handles.etxt_freqlinearstep,'Enable','off');
        case 'rbtn_freqlinear' % if frequency spectra = linear
            set(handles.pop_freqoctstart,'Enable','off');
            set(handles.pop_freqoctend,'Enable','off');
            set(handles.pop_freq13octstart,'Enable','off');
            set(handles.pop_freq13octend,'Enable','off');
            set(handles.etxt_freqlinearstart,'Enable','on');
            set(handles.etxt_freqlinearend,'Enable','on');
            set(handles.etxt_freqlinearstep,'Enable','on');
    end
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% BUTTON DOWN FUNCTIONS                                               %%%
%%% - Functions that are executed when the user clicks on the uicontrol %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function axes_system_ButtonDownFcn(hObject, eventdata, handles)
%
    handles = guidata(hObject);
    set(hObject,'Interruptible','off');
    if ~(strcmp(get(handles.mainfig,'SelectionType'),'open') || strcmp(get(handles.mainfig,'SelectionType'),'extend'))
        data = getappdata(mainui,'data');
        if data.numss
            for ii = 1:data.numss
                set(data.subsystems(ii).img_handles,'Selected','off')
            end
            setappdata(mainui,'data',data)
        end
    end
    guidata(hObject, handles);
%%
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SUB FUNCTIONS                                                     %%%
%%% - Functions that are executed when called on from other functions %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function img_click(hObject,eventdata,handles)
%
    handles = guidata(hObject);
    set(hObject,'Interruptible','off');
    if ~(strcmp(get(handles.mainfig,'SelectionType'),'open') || strcmp(get(handles.mainfig,'SelectionType'),'extend'))
        data = getappdata(mainui,'data');
        clickpoint = get(gca,'CurrentPoint');
        xclick = clickpoint(1,1);
        yclick = clickpoint(1,2);
        for ii = 1:data.numss
            if ((data.subsystems(ii).coord(1)-4<xclick && data.subsystems(ii).coord(1)+4>xclick) && (data.subsystems(ii).coord(2)-4<yclick && data.subsystems(ii).coord(2)+4>yclick))
                if strcmp(get(data.subsystems(ii).img_handles,'Selected'),'on')
                    set(data.subsystems(ii).img_handles,'Selected','off')
                else
                    set(data.subsystems(ii).img_handles,'Selected','on')
                end
            end
        end
        setappdata(mainui,'data',data)
    end
    guidata(hObject, handles);
%%

function update_axes(hObject,eventdata,handles)
%
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    cla(handles.axes_system,'reset')
    hold on
    axis(handles.axes_system,[0 100 0 70])
    if data.numss
        for ii = 1:data.numss
            x = data.subsystems(ii).coord(1);
            y = data.subsystems(ii).coord(2);
            drawimage(data.subsystems(ii).type,ii,x,y)
    %         text(x+2,y+4,num2str(data.numss),'BackgroundColor','k','Color','w')
        end
    end
    if data.numcon
        for ii = 1:data.numcon
            from_ss = data.connections(ii).subsystems(1);
            to_ss = data.connections(ii).subsystems(2);
            line([data.subsystems(from_ss).coord(1) data.subsystems(to_ss).coord(1)],[data.subsystems(from_ss).coord(2) data.subsystems(to_ss).coord(2)]), hold on
            if data.subsystems(from_ss).coord(1)<data.subsystems(to_ss).coord(1)
                x_coord = data.subsystems(from_ss).coord(1)+abs(data.subsystems(from_ss).coord(1)-data.subsystems(to_ss).coord(1))/2;
            else
                x_coord = data.subsystems(from_ss).coord(1)-abs(data.subsystems(from_ss).coord(1)-data.subsystems(to_ss).coord(1))/2;
            end
            if data.subsystems(from_ss).coord(2)<data.subsystems(to_ss).coord(2)
                y_coord = data.subsystems(from_ss).coord(2)+abs(data.subsystems(from_ss).coord(2)-data.subsystems(to_ss).coord(2))/2;
            else
                y_coord = data.subsystems(from_ss).coord(2)-abs(data.subsystems(from_ss).coord(2)-data.subsystems(to_ss).coord(2))/2;
            end
            text(x_coord,y_coord,num2str(ii),'BackgroundColor','b','Color','w')
        end
    end
    guidata(hObject,handles);
%%

function drawimage(type,nr,x,y)
%
    data = getappdata(mainui,'data');
    for ii=1:length(data.subtypes)
        if strcmp(data.subtypes(ii).name,type)
            hold on
            eval(['data.subsystems(nr).img_handles = image([x-4 x+4],[y+4 y-4],data.subtypes(ii).value)'])
            text(x+2,y+4,num2str(nr),'BackgroundColor','k','Color','w')
            return
        end
    end
    setappdata(mainui,'data',data)
%%

function update_popmenus(hObject)
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    if data.numss
        set(handles.pop_delsubs,'String',num2cell(1:data.numss)')
        set(handles.pop_subsnr,'String',num2cell(1:data.numss)')
        set(handles.pop_input_subsnr,'String',num2cell(1:data.numss)')
    else
        set(handles.pop_delsubs,'String','N/A')
        set(handles.pop_subsnr,'String','N/A')
        set(handles.pop_input_subsnr,'String','N/A')
    end
    if data.numcon
        set(handles.pop_delcon,'String',num2cell(1:data.numcon)')
        set(handles.pop_connr,'String',num2cell(1:data.numcon)')
    else
        set(handles.pop_delcon,'String','N/A')
        set(handles.pop_connr,'String','N/A')
    end
    guidata(hObject, handles);
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% TEMP                                               %%%
%%% - Temporary function, not present in final release %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function btn_test_Callback(hObject, eventdata, handles)
%
    handles = guidata(hObject);
    data = getappdata(mainui,'data');
    data.handles = handles;
    save temp.mat data
%%

%%%%%%%%%%%%%%%%%%%%%%%
%%% NOT SORTED      %%%
%%% - new functions %%%
%%%%%%%%%%%%%%%%%%%%%%%


% --- Executes on button press in btn_freq_set.
function btn_freq_set_Callback(hObject, eventdata, handles)
% hObject    handle to btn_freq_set (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    if ~isfield(data,'f')
        set(handles.txt_error2,'String','Frequency has to be set before defining non-linear damping')
        return
    end
    set(hObject,'Interruptible','off');
    lossui(data.f);
%     dmp = lossui(data.f);
%     subs_nr = get(handles.pop_subsnr,'Value');
%     data.subsystems(subs_nr).values.damping.b = dmp{1};
%     data.subsystems(subs_nr).values.damping.l = dmp{2};
%     data.subsystems(subs_nr).values.damping.s = dmp{3};

% --- Executes on button press in btn_exitation.
function btn_exitation_Callback(hObject, eventdata, handles)
% hObject    handle to btn_exitation (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
    handles = guidata(hObject); % Get handles
    data = getappdata(mainui,'data');
    if ~isfield(data,'f')
        set(handles.txt_error2,'String','Frequency has to be set before defining non-linear damping')
        return
    end
    set(hObject,'Interruptible','off');
    subs_nr = get(handles.pop_input_subsnr,'Value');
    switch data.subsystems(subs_nr).type
        case 'plate'
            input_power = exitation('plate',data.f,data.subsystems(subs_nr).values);
        case 'cavity'
            input_power = exitation('cavity',data.f);
    end
% input_power = exitation(data);

% --- Executes on button press in btn_freq_ok.
function btn_freq_ok_Callback(hObject, eventdata, handles)
% hObject    handle to btn_freq_ok (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
    handles = guidata(hObject);
    data = getappdata(mainui,'data');
    load frequencies.mat fr13oct froct
    if get(handles.rbtn_freqoct,'Value');
            start_pos = get(handles.pop_freqoctstart,'Value');
            end_pos = get(handles.pop_freqoctend,'Value');
            if start_pos > end_pos
                set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
                return
            end
            data.f = frequency(froct(start_pos),froct(end_pos),'octave');
        elseif get(handles.rbtn_freq13oct,'Value');
            start_pos = get(handles.pop_freq13octstart,'Value');
            end_pos = get(handles.pop_freq13octend,'Value');
            if start_pos > end_pos
                set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
                return
            end
            data.f = frequency(fr13oct(start_pos),fr13oct(end_pos),'13octave');
        elseif get(handles.rbtn_freqlinear,'Value');
            start_freq = str2double(get(handles.etxt_freqlinearstart,'String'));
            end_freq = str2double(get(handles.etxt_freqlinearend,'String'));
            if start_freq > end_freq
                set(handles.txt_error2,'String','Start frequency can not be higher than the end frequency')
                return
            end
            step = str2double(get(handles.etxt_freqlinearstep,'String'));
            data.f = frequency(start_freq,end_freq,'linear',step);
    end
    guidata(hObject, handles);
    setappdata(mainui,'data',data)


% --- Executes when selected object is changed in btng_input_type.
function btng_input_type_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to the selected object in btng_input_type 
% eventdata  structure with the following fields (see UIBUTTONGROUP)
%	EventName: string 'SelectionChanged' (read only)
%	OldValue: handle of the previously selected object or empty if none was selected
%	NewValue: handle of the currently selected object
% handles    structure with handles and user data (see GUIDATA)
    switch get(eventdata.NewValue,'Tag')   % Get Tag of selected object
        case 'rbtn_input_linear' % if frequency spectra = octave band
            set(handles.btn_exitation,'Visible','off');
            set(handles.txt_input_lin_b1,'Visible','on');
            set(handles.etxt_input_linear_b,'Visible','on');
            set(handles.txt_input_lin_b2,'Visible','on');
            set(handles.txt_input_lin_l1,'Visible','on');
            set(handles.etxt_input_linear_l,'Visible','on');
            set(handles.txt_input_lin_l2,'Visible','on');
            set(handles.txt_input_lin_s1,'Visible','on');
            set(handles.etxt_input_linear_s,'Visible','on');
            set(handles.txt_input_lin_s2,'Visible','on');
            set(handles.btn_input_ok,'Visible','on');
        case 'rbtn_input_predef' % if frequency spectra = 1/3-octave band
            set(handles.btn_exitation,'Visible','on');
            set(handles.txt_input_lin_b1,'Visible','off');
            set(handles.etxt_input_linear_b,'Visible','off');
            set(handles.txt_input_lin_b2,'Visible','off');
            set(handles.txt_input_lin_l1,'Visible','off');
            set(handles.etxt_input_linear_l,'Visible','off');
            set(handles.txt_input_lin_l2,'Visible','off');
            set(handles.txt_input_lin_s1,'Visible','off');
            set(handles.etxt_input_linear_s,'Visible','off');
            set(handles.txt_input_lin_s2,'Visible','off');
            set(handles.btn_input_ok,'Visible','off');
    end
    guidata(hObject, handles);


% --- Executes when selected object is changed in btng_subslosstype.
function btng_subslosstype_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to the selected object in btng_subslosstype 
% eventdata  structure with the following fields (see UIBUTTONGROUP)
%	EventName: string 'SelectionChanged' (read only)
%	OldValue: handle of the previously selected object or empty if none was selected
%	NewValue: handle of the currently selected object
% handles    structure with handles and user data (see GUIDATA)
switch get(eventdata.NewValue,'Tag')
    case 'rbtn_subslineardamp'
        set(handles.etxt_subslineardamp,'Visible','on');
        set(handles.txt_subslineardamp,'Visible','on');
        set(handles.btn_freq_set,'Visible','off');
    case 'rbtn_freqdamp'
        set(handles.etxt_subslineardamp,'Visible','off');
        set(handles.txt_subslineardamp,'Visible','off');
        set(handles.btn_freq_set,'Visible','on');
end
    


% --- Executes during object creation, after setting all properties.
function txt_conarea_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conarea (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_conaream2_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conaream2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_conlength_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conlength (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_conlengthm_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conlengthm (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_conang_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conang (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_conangles_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_conangles (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_plateangdeg_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_plateangdeg (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function btn_conprop_angle_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to btn_conprop_angle (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_b1_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_b1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_b2_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_b2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function btn_exitation_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to btn_exitation (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_l1_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_l1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_l2_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_l2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_s1_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_s1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function txt_input_lin_s2_CreateFcn(hObject, eventdata, handles)
set(hObject,'Visible','off')
% hObject    handle to txt_input_lin_s2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
