%**************************************************************************
% Input data file for the SEAlab
%**************************************************************************
% Example file for cavity-plate-cavity
%
% 110511 Patrik Andersson
clear all
cd ..
enablepaths

% File name to which the results are saved in the results/ folder
%**************************************************************************
save_name='results_cavity_plate_cavity';

% Global parameters
%**************************************************************************
load(['data' filesep 'frequencies.mat'])
data.f=fr13oct(12:end); % Frequency vector
data.numss=3;% Number of subsystems
data.numcon=1;% Number of connections 
    % (Cavity-plate-cavity is treated as one connection called 'leaf wall')

   
% Subsystem parameters
%**************************************************************************

% Subsystem 1: Cavity 1
ns=1;
data.subsystems(ns).type='cavity'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'fluids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves (osbolete)
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves (osbolete)
data.subsystems(ns).values.dim=[4 3 3]; % Cavity dimensions [length width height]
data.subsystems(ns).values.volume=prod(data.subsystems(ns).values.dim); % Cavity volume
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem (obsolete)
data.subsystems(ns).values.input_power.power.l = 1; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem (obsolete)

% Subsystem 2: Plate
ns=2;
data.subsystems(ns).type='plate'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'solids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves
data.subsystems(ns).values.dim=[3 3]; % Plate dimensions [width and length]
data.subsystems(ns).values.thickness=0.01; % Thickness of plate
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem


% Subsystem 3: Cavity 2
ns=3;
data.subsystems(ns).type='cavity'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'fluids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves (osbolete)
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves (osbolete)
data.subsystems(ns).values.dim=[3 3 3]; % Cavity dimensions [length width height]
data.subsystems(ns).values.volume=prod(data.subsystems(ns).values.dim); % Cavity volume
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem (obsolete)
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem (obsolete)



% Connection/junction parameters
%**************************************************************************

% Connection 1: Leaf wall (cavity-plate-cavity)
cn=1;
% Type of connection:
data.connections(cn).type = 'leaf wall';
% Index of the subsystem describing the plate in the connection
data.connections(cn).plate_nr = 2;
% Indexes of the subsystems describing the cavities in the connection
data.connections(cn).cavity_nr = [1 3];
% Indexes of the subsystems in this connection (cavity-plate-cavity):
data.connections(cn).subsystems=[data.connections(cn).cavity_nr(1),data.connections(cn).plate_nr,data.connections(cn).cavity_nr(2)];
% Connection area
data.connections(cn).values.area=prod(data.subsystems(2).values.dim);


%**************************************************************************
% Call the main program
%**************************************************************************
SEAlab_v0p1

%**************************************************************************
% Save the results
%**************************************************************************
save(['results' filesep save_name],'data')
