%**************************************************************************
% Input data file for the SEAlab
%**************************************************************************
% Example file for double wall (room-plate-cavity-plate-room)
%   including the non-resonant double wall transmission between the rooms
%
% 110518 Patrik Andersson
clear all
cd ..
enablepaths

% File name to which the results are saved in the results/ folder
%**************************************************************************
save_name='results_double_wall';

% Global parameters
%**************************************************************************
load(['data' filesep 'frequencies.mat'])
data.f=fr13oct(12:end); % Frequency vector
data.numss=5;% Number of subsystems
data.numcon=1;% Number of connections
    % (a double wall is is treated as one connection called 'double wall')

   
% Subsystem parameters
%**************************************************************************

% Subsystem 1: Cavity 1 (Room)
ns=1;
data.subsystems(ns).type='cavity'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'fluids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves (osbolete)
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves (osbolete)
data.subsystems(ns).values.dim=[4 3 3]; % Cavity dimensions [width height length]
data.subsystems(ns).values.volume=prod(data.subsystems(ns).values.dim); % Cavity volume
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem (obsolete)
data.subsystems(ns).values.input_power.power.l = 1; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem (obsolete)

% Subsystem 2: Plate 1
ns=2;
data.subsystems(ns).type='plate'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'solids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves
data.subsystems(ns).values.dim=[3 3]; % Plate dimensions [width and length]
data.subsystems(ns).values.thickness=0.01; % Thickness of plate
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem

% Subsystem 3: Cavity 2 (Cavity between walls)
ns=3;
data.subsystems(ns).type='cavity'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'fluids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves (osbolete)
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves (osbolete)
data.subsystems(ns).values.dim=[3 3 0.09]; % Cavity dimensions [width height length]
data.subsystems(ns).values.volume=prod(data.subsystems(ns).values.dim); % Cavity volume
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem (obsolete)
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem (obsolete)

% Subsystem 4: Plate 2
ns=4;
data.subsystems(ns).type='plate'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'solids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves
data.subsystems(ns).values.dim=[3 3]; % Plate dimensions [width and length]
data.subsystems(ns).values.thickness=0.01; % Thickness of plate
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem

% Subsystem 5: Cavity 3 (Room)
ns=5;
data.subsystems(ns).type='cavity'; % Type of subsystem
data.subsystems(ns).values.material=1; % Material data number refering to
                                        %   the variable 'fluids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves (osbolete)
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves (osbolete)
data.subsystems(ns).values.dim=[3 3 3]; % Cavity dimensions [width height length]
data.subsystems(ns).values.volume=prod(data.subsystems(ns).values.dim); % Cavity volume
data.subsystems(ns).values.input_power.power.b = 0; % Input power to bending wave subsystem (obsolete)
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem (obsolete)

% Connection/junction parameters
%**************************************************************************
% Connection 1: Double wall (cavity-plate-cavity-plate-cavity)
cn=1;
% Type of connection:
data.connections(cn).type = 'double wall';
% Index of the subsystems in this connetion, 
%   have to have be order room-plate-cavity-plate-room
data.connections(cn).subsystems=[1 2 3 4 5];
% Connection area
data.connections(cn).values.area=prod(data.subsystems(2).values.dim);

%**************************************************************************
% Call the main program
%**************************************************************************
SEAlab_v0p1

%**************************************************************************
% Save the results
%**************************************************************************
save(['results' filesep save_name],'data')
