%**************************************************************************
% Input data file for the SEAlab
%**************************************************************************
% Example file for for connected plates; one junction where tw0 plates
%   are connected in a right angle
%
% 110511 Patrik Andersson
clear all
cd ..
enablepaths

% File name to which the results are saved in the results/ folder
%**************************************************************************
save_name='results_two_plates';

% Global parameters
%**************************************************************************
load(['data' filesep 'frequencies.mat'])
data.f=fr13oct(20:end); % Frequency vector
data.numss=2;% Number of plates
data.numcon=1;% Number of connections

% Subsystem parameters
%**************************************************************************

% Subsystem 1: Plate 1
ns=1;
data.subsystems(ns).type='plate'; % Type of subsystem
data.subsystems(ns).values.material=11; % Material data number refering to
                                        %   the variable 'solids' in 
                                        %   data/physicalproperties.mat
data.subsystems(ns).values.damping.b=0.01; % Loss factor of bending waves
data.subsystems(ns).values.damping.l=0.01; % Loss factor of longitudinal waves
data.subsystems(ns).values.damping.s=0.01; % Loss factor of shear waves
data.subsystems(ns).values.dim=[0.9 0.4]; % Plate dimensions [width and length]
data.subsystems(ns).values.thickness=0.001; % Thickness of plate
data.subsystems(ns).values.input_power.power.b = 1; % Input power to bending wave subsystem
data.subsystems(ns).values.input_power.power.l = 0; % Input power to longitudinal wave subsystem
data.subsystems(ns).values.input_power.power.s = 0; % Input power to shear wave subsystem

% Subsystem 2: Plate 2
ns=2;
data.subsystems(ns).type='plate';
data.subsystems(ns).values.material=11;
data.subsystems(ns).values.damping.b=0.01;
data.subsystems(ns).values.damping.l=0.01;
data.subsystems(ns).values.damping.s=0.01;
data.subsystems(ns).values.dim=[0.9 0.7];
data.subsystems(ns).values.thickness=0.001;
data.subsystems(ns).values.input_power.power.b = 0;
data.subsystems(ns).values.input_power.power.l = 0;
data.subsystems(ns).values.input_power.power.s = 0;


% Connection/junction parameters
%**************************************************************************
% Connection 1
cn=1;
% Type of connection:
data.connections(cn).type = 'plates';
% Index of plates in this connection (refering to the index of the plates 
%   defined above):
data.connections(cn).subsystems=[1 2];
% The angles of plates in a plate-plate line junction (See JC Figure 4.1):                        
data.connections(cn).values.angles=[0 90];
% Conncetion length:
data.connections(cn).values.length=0.9;
% Number of integration points when integrating transmission coefficient
%   over angles of incident waves
data.connections(cn).values.num_angles=1000;

%**************************************************************************
% Call the main program
%**************************************************************************
SEAlab_v0p1

%**************************************************************************
% Save the results
%**************************************************************************
save(['results' filesep save_name],'data')
