clear all
load('../results/results_cavity.mat')


%******************************************************************************
% Energy in subsystems
%******************************************************************************
% data.subsystems(n).Energy.b : Bending wave energy of subsystem n
% data.subsystems(n).Energy.l : Longitudinal wave energy of subsystem n
% data.subsystems(n).Energy.s : Shear wave energy of subsystem n
figure(1)
semilogx(data.f,10*log10(data.subsystems(1).Energy.l),'bo-')
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Energy level [dB re. 1J]')
legend('Cavity',3)


%******************************************************************************
% Engineering units, sound pressure levels
%******************************************************************************
% rms-pressure squared are given by subsystem energy times rho*c^2 
%   divided by subsystem volume
ii=[1]; % Indexes of the subsystems defining the cavities
for nn=1:length(ii)
    V=data.subsystems(ii(nn)).values.volume;
    c=data.subsystems(ii(nn)).values.c;
    rho=data.subsystems(ii(nn)).values.rho;
    prms2(nn,:)=data.subsystems(ii(nn)).Energy.l*rho*c^2/V;
end
figure(2)
semilogx(data.f,10*log10(prms2(1,:)),'bo-')
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Sound pressure level [dB re. 20 {\mu}Pa]')
legend('Cavity',3)
