clear all
load('../results/results_cavity_plate_cavity.mat')


%******************************************************************************
% Energy in subsystems
%******************************************************************************
% data.subsystems(n).Energy.b : Bending wave energy of subsystem n
% data.subsystems(n).Energy.l : Longitudinal wave energy of subsystem n
% data.subsystems(n).Energy.s : Shear wave energy of subsystem n
figure(1)
semilogx(data.f,10*log10(data.subsystems(1).Energy.l),'bo-')
hold on
semilogx(data.f,10*log10(data.subsystems(2).Energy.b),'bo--')
semilogx(data.f,10*log10(data.subsystems(3).Energy.l),'bo:')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Energy level [dB re. 1J]')
legend( 'Cavity 1 L','Plate 1 B','Cavity 2 L',3)


%******************************************************************************
% Engineering units, sound pressure levels
%******************************************************************************
% rms-pressure squared are given by subsystem energy times rho*c^2 
%   divided by subsystem volume
ii=[1 3]; % Indexes of the subsystems defining the cavities
for nn=1:length(ii)
    V=data.subsystems(ii(nn)).values.volume;
    c=data.subsystems(ii(nn)).values.c;
    rho=data.subsystems(ii(nn)).values.rho;
    prms2(nn,:)=data.subsystems(ii(nn)).Energy.l*rho*c^2/V;
end
figure(2)
semilogx(data.f,10*log10(prms2(1,:)),'bo-')
hold on
semilogx(data.f,10*log10(prms2(2,:)),'bo--')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Sound pressure level [dB re. 20 {\mu}Pa]')
legend('Cavity 1','Cavity 2',3)


%******************************************************************************
% Engineering units, velocity levels
%******************************************************************************
% rms-velocity squared are given by subsystem energy divided by subsystem mass
ii=2; % Indexes of the subsystems defining the plate
thickness=data.subsystems(ii).values.thickness;
length=data.subsystems(ii).values.dim(1);
width=data.subsystems(ii).values.dim(2);
volume=length*width*thickness;
mass(ii)=volume*data.subsystems(ii).values.rho;


figure(3)
semilogx(data.f,10*log10(data.subsystems(2).Energy.b/mass(2)),'bo-.')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Velocity level [dB re. 1 m/s]')
legend('Plate B',3)


%******************************************************************************
% Radiation efficiency
%******************************************************************************
% data.connections(n).radiation_eff(m).rad
%   n - connection number
%   m - cavity index in the connection
figure(4)
semilogx(data.f,10*log10(data.connections(1).radiation_eff(1).rad),'o-')
hold on
semilogx(data.f,10*log10(data.connections(1).radiation_eff(2).rad),'o--')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Radiation efficiency [dB]')
legend('Plate B to Cavity 1','Plate B to Cavity 2',3)

%******************************************************************************
% Coupling loss factors at the Junction
%******************************************************************************
% data.connections(n1).clf(n2,n3,n4).n5 : 
%       n1 : number of the junction
%       n2 : from subsystem n2 at the specific junction
%       n3 : to subsystem n3 at the specific junction
% (n2 and n3 refers to the indexes of the list data.connections(n1).subsystems 
%       where the index of the connected cavities and plate are listed)
%       n4 : wave type in subsystem n2 at the juction
%            n4=1 - bending, n4=2 - long., and n4=3 - shear
%       n5 : wave type in subsystem n3 at the junction
%            n5='b' - bending, n5='l' - long., and n5='s' - shear
CLF_1=data.connections(1).clf(1,2,2).b;clf1='Cavity 1 to Plate B';
CLF_2=data.connections(1).clf(1,3,2).l;clf2='Cavity 1 to Cavity 2';
CLF_3=data.connections(1).clf(2,1,1).l;clf3='Plate B to Cavity 1';
CLF_4=data.connections(1).clf(2,3,1).l;clf4='Plate B to Cavity 2';
CLF_5=data.connections(1).clf(1,2,2).b;clf5='Cavity 2 to Plate B';
CLF_6=data.connections(1).clf(1,3,2).l;clf6='Cavity 2 to Cavity 1';

figure(5)
semilogx(data.f,10*log10(CLF_1),'bo-','LineWidth',1)
hold on
semilogx(data.f,10*log10(CLF_2),'go-','LineWidth',1)
semilogx(data.f,10*log10(CLF_3),'ro-','LineWidth',1)
semilogx(data.f,10*log10(CLF_4),'ko-','LineWidth',1)
semilogx(data.f,10*log10(CLF_5),'mo-','LineWidth',1)
semilogx(data.f,10*log10(CLF_6),'co-','LineWidth',1)
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Coupling loss factors [dB]')
title('CLF Junction 1')
legend(clf1,clf2,clf3,clf4,clf5,clf6,3)
