clear all
load('../results/results_plate_cavity.mat')


%******************************************************************************
% Energy in subsystems
%******************************************************************************
% data.subsystems(n).Energy.b : Bending wave energy of subsystem n
% data.subsystems(n).Energy.l : Longitudinal wave energy of subsystem n
% data.subsystems(n).Energy.s : Shear wave energy of subsystem n
figure(1)
semilogx(data.f,10*log10(data.subsystems(1).Energy.b),'bo-')
hold on
semilogx(data.f,10*log10(data.subsystems(2).Energy.l),'bo--')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Energy level [dB re. 1J]')
legend('Plate B','Cavity',3)


%******************************************************************************
% Engineering units, sound pressure levels
%******************************************************************************
% rms-pressure squared are given by subsystem energy times rho*c^2 
%   divided by subsystem volume
ii=[2]; % Indexes of the subsystems defining the cavities
for nn=1:length(ii)
    V=data.subsystems(ii(nn)).values.volume;
    c=data.subsystems(ii(nn)).values.c;
    rho=data.subsystems(ii(nn)).values.rho;
    prms2(nn,:)=data.subsystems(ii(nn)).Energy.l*rho*c^2/V;
end
figure(2)
semilogx(data.f,10*log10(prms2(1,:)),'bo-')
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Sound pressure level [dB re. 20 {\mu}Pa]')
legend('Cavity',3)


%******************************************************************************
% Engineering units, velocity levels
%******************************************************************************
% rms-velocity squared are given by subsystem energy divided by subsystem mass
ii=1; % Indexes of the subsystems defining the plate
thickness=data.subsystems(ii).values.thickness;
length=data.subsystems(ii).values.dim(1);
width=data.subsystems(ii).values.dim(2);
volume=length*width*thickness;
mass(ii)=volume*data.subsystems(ii).values.rho;


figure(3)
semilogx(data.f,10*log10(data.subsystems(1).Energy.b/mass(1)),'bo-.')
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Velocity level [dB re. 1 m/s]')
legend('Plate B',3)


%******************************************************************************
% Radiation efficiency
%******************************************************************************
% data.connections(n).radiation_eff(m).rad
%   n - connection number
%   m - cavity index in the connection
figure(4)
semilogx(data.f,10*log10(data.connections(1).radiation_eff(1).rad),'o-')
xlim([10 20000])
set(gca,'FontSize',16)
xlabel('Frequency [Hz]')
ylabel('Radiation efficiency [dB]')
legend('Plate B to Cavity',3)

%******************************************************************************
% Coupling loss factors at the Junction
%******************************************************************************
% data.connections(n1).clf(n2,n3,n4).n5 : 
%       n1 : number of the junction
%       n2 : from subsystem n2 at the specific junction
%       n3 : to subsystem n3 at the specific junction
% (n2 and n3 refers to the indexes of the list data.connections(n1).subsystems 
%       where the index of the connected cavities and plate are listed)
%       n4 : wave type in subsystem n2 at the juction
%            n4=1 - bending, n4=2 - long., and n4=3 - shear
%       n5 : wave type in subsystem n3 at the junction
%            n5='b' - bending, n5='l' - long., and n5='s' - shear
CLF_1=data.connections(1).clf(1,2,1).l;clf1='Plate B to Cavity';
CLF_2=data.connections(1).clf(2,1,2).b;clf2='Cavity to Plate B';

figure(5)
semilogx(data.f,10*log10(CLF_1),'bo-','LineWidth',1)
hold on
semilogx(data.f,10*log10(CLF_2),'go-','LineWidth',1)
hold off
xlim([10 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Coupling loss factors [dB]')
title('CLF Junction 1')
legend(clf1,clf2,3)
