clear all
load('../results/results_two_plates.mat')

%******************************************************************************
% Energy in subsystems
%******************************************************************************
% data.subsystems(n).Energy.b : Bending wave energy of plate n
% data.subsystems(n).Energy.l : Longitudinal wave energy of plate n
% data.subsystems(n).Energy.s : Shear wave energy of plate n
figure(1)
semilogx(data.f,10*log10(data.subsystems(1).Energy.b),'bo-')
hold on
semilogx(data.f,10*log10(data.subsystems(1).Energy.l),'bo--')
semilogx(data.f,10*log10(data.subsystems(1).Energy.s),'bo:')
semilogx(data.f,10*log10(data.subsystems(2).Energy.b),'go-')
semilogx(data.f,10*log10(data.subsystems(2).Energy.l),'go--')
semilogx(data.f,10*log10(data.subsystems(2).Energy.s),'go:')
hold off
xlim([100 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Energy level [dB re. 1J]')
legend( 'Plate 1 B','Plate 1 L','Plate 1 S',...
        'Plate 2 B','Plate 2 L','Plate 2 S',3)

%******************************************************************************
% Engineering units, velocity levels
%******************************************************************************
% rms-velocity squared are given by subsystem energy divided by subsystem mass
for ii=1:data.numss
    thickness=data.subsystems(ii).values.thickness;
    length=data.subsystems(ii).values.dim(1);
    width=data.subsystems(ii).values.dim(2);
    volume=length*width*thickness;
    mass(ii)=volume*data.subsystems(ii).values.rho;
end
figure(2)
semilogx(data.f,10*log10(data.subsystems(1).Energy.b/mass(1)),'bo-')
hold on
semilogx(data.f,10*log10(data.subsystems(2).Energy.b/mass(2)),'bo--')
hold off
xlim([100 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Velocity level [dB re. 1 m/s]')
legend('Plate 1 B','Plate 2 B',3)


%******************************************************************************
% Coupling loss factors Junction 1
%******************************************************************************
% data.connections(n1).clf(n2,n3,n4).n5 : 
%       n1 : number of the junction
%       n2 : from plate n2 at the specific junction
%       n3 : to plate n3 at the specific junction
% (n2 and n3 refers to the indexes of the list data.connections(n1).subsystems 
%       where the index of the connected plates are listed)
%       n4 : wave type in plate n2 at the juction
%            n4=1 - bending, n4=2 - long., and n4=3 - shear
%       n5 : wave type in plate n3 at the junction
%            n5='b' - bending, n5='l' - long., and n5='s' - shear
CLF_1=data.connections(1).clf(1,2,1).b;clf1='Plate 1 B-Plate 2 B';
CLF_2=data.connections(1).clf(1,2,1).l;clf2='Plate 1 B-Plate 2 L';
CLF_3=data.connections(1).clf(1,2,1).s;clf3='Plate 1 B-Plate 2 S';
CLF_4=data.connections(1).clf(1,2,2).b;clf4='Plate 1 L-Plate 2 B';
CLF_5=data.connections(1).clf(1,2,2).l;clf5='Plate 1 L-Plate 2 L';
CLF_6=data.connections(1).clf(1,2,2).s;clf6='Plate 1 L-Plate 2 S';

figure(3)
semilogx(data.f,10*log10(CLF_1),'bo-','LineWidth',1)
hold on
semilogx(data.f,10*log10(CLF_2),'go-','LineWidth',1)
semilogx(data.f,10*log10(CLF_3),'ro-','LineWidth',1)
semilogx(data.f,10*log10(CLF_4),'ko-','LineWidth',1)
semilogx(data.f,10*log10(CLF_5),'mo-','LineWidth',1)
semilogx(data.f,10*log10(CLF_6),'co-','LineWidth',1)
hold off
xlim([100 20000])
set(gca,'FontSize',14)
xlabel('Frequency [Hz]')
ylabel('Coupling loss factors [dB]')
title('CLF Junction 1')
legend(clf1,clf2,clf3,clf4,clf5,clf6,3)

